function plot_fragments(fn);
% plot_fragments(fn);
%
% e.g., plot_fragments('t29_lwwj2n_m17_lgwe7s');
%

if nargin < 1
   fn = 't29_lwwj2n_m17_lgwe7s';
end

wavExt = '.wav';
rateExt = '.rate64d';
frmsegExt = '.frmseg';
f0candsExt = '.f0cands';
tracksExt = '.f0tracks';
maskExt = '.masks';
groupsExt = '.groups';

fullname = strcat(fn, wavExt);
if exist(fullname, 'file') == 0
   error('Can not find wav file %s.', fullname);
end
[x,fs] = wavread(fullname);

nsubplots = 3;
current_plot = 0;
if nsubplots > current_plot
  current_plot = current_plot + 1;
  subplot(nsubplots,1,current_plot);
  
  f0s = read_floats(strcat(fn,f0candsExt), 4);

  plot(f0s(1,:),'r.');
  hold on;
  plot(f0s(2,:),'bx');
  plot(f0s(3,:),'bx');
  plot(f0s(4,:),'bx');
  hold off;
  axis([1 size(f0s,2) 10 400]);
  set(gca,'XTick',[]);
  set(gca,'YTickLabel',{'100Hz','200Hz','300Hz'}, 'FontSize', 12);
  set(gca,'YTick',[100,200,300]);
  ylabel('F0', 'FontSize', 12);

  title('F0 candidates (dot - stronger source, x - weaker source)', 'FontSize', 12);
  
end

if nsubplots > current_plot
  current_plot = current_plot + 1;
    
  tracks = read_floats(strcat(fn,tracksExt), 2);

  subplot(nsubplots,1,current_plot);
  plot(tracks(1,:),'ro');
  hold on;
  plot(tracks(2,:),'bo');
  
  hold off;
  axis([1 size(f0s,2) 10 400]);
  set(gca,'XTick',[]);
  set(gca,'YTickLabel',{'100Hz','200Hz','300Hz'}, 'FontSize', 12);
  set(gca,'YTick',[100,200,300]);
  ylabel('F0', 'FontSize', 12);
  
  title('Linked F0 tracks', 'FontSize', 12);
end

if nsubplots > current_plot
  current_plot = current_plot + 1;
  
  myfrag_harm = read_shorts(strcat(fn, groupsExt), 64);

  subplot(nsubplots,1,current_plot)
  myfrag_harm = change_labels_for_plotting(myfrag_harm);
  imagesc(myfrag_harm);
  axis xy;
  
  set(gca,'YTickLabel',{'50Hz','8KHz'}, 'FontSize', 12);
  set(gca,'YTick',[1,64]);
  ylabel('Centre Freq', 'FontSize', 12);
  title('Formed harmonic spectro-temporal fragments', 'FontSize', 12);
end


%colormap(1-gray);
%print -depsc2 ../graphics/fragments.eps





%--------------------------------------------------------------------------

function x = read_floats(fname, nchnls, byteorder);

if nargin < 3
  byteorder = 'l';
end
if nargin < 2
  nchnls = 64;
end

[fid, msg] = fopen(fname, 'r', byteorder);
if (fid < 0)
  fprintf('File not found: %s\n', fname);
else
  x = fread(fid, [nchnls,inf], 'float');
  fclose(fid);
end


%--------------------------------------------------------------------------
function x = read_shorts(fname, nchnls, byteorder);

if nargin < 3
  byteorder = 'l';
end
if nargin < 2
  nchnls = 64;
end

[fid, msg] = fopen(fname, 'r', byteorder);
if (fid < 0)
  fprintf('File not found: %s\n', fname);
else
  x = fread(fid, [nchnls,inf], 'int16');
  fclose(fid);
end


%--------------------------------------------------------------------------
function frag2 = change_labels_for_plotting(frag)

labs = unique(frag);

frag2 = zeros(size(frag));

for i = 2:length(labs)
    frag2(frag==labs(i)) = i-1;
end

