
#ifndef __AUXILIARY_H
#define __AUXILIARY_H

#include <vector>

typedef unsigned char           byte;
typedef double                  Float;
typedef std::vector<int>        VectorInt;
typedef std::vector<VectorInt>  MatrixInt;
typedef std::vector<Float>      VectorF;
typedef std::vector<VectorF>    MatrixF;

class AudioWav { 
public:
  AudioWav() : _data(), _fsHz(0) {}
  const VectorF& data() const { return _data; }
  Float& operator[](int n) { return _data[n]; }
  const Float & operator[](int n) const { return _data[n]; }
  int size() const { return _data.size(); }
  void clear() { _data.clear(); }
  void add(Float f) { _data.push_back(f); }
  int fsHz() const { return _fsHz; }
  void setFsHz(int fsHz) { _fsHz = fsHz; }
  int read(const char* fname, char endian = 'l');

private:
  VectorF  _data;
  int      _fsHz; // sampling rate in Hz
};

// Return the number of frames loaded
int read_float32(MatrixF & mat, const char* fn, int numChans, int offset = 0, bool byteswap = false);
void compute_snrmap_log(MatrixF& snrmap, const MatrixF& mix, const MatrixF& noise);
void compute_softmask_sigmoid(MatrixF& snrmask, const MatrixF& snrmap, const float snrthr, const float slope);

void swap_2bytes(short* x);
void swap_4bytes(float* x);

// For debugging...
void print_vector ( const int* x, const int len );
void print_vector ( const Float* x, const int len );

#endif //__AUXILIARY_H

