
/***************************************************************************
 * Ning Ma, University of Sheffield
 * n.ma@dcs.shef.ac.uk, 12 Jun 2007
 ***************************************************************************/

#ifndef __PITCH_TRACKER_H
#define __PITCH_TRACKER_H

#include <math.h>
#include "auxiliary.h"

const int NUM_F0CANDS = 4;    // 1 F0 candidate for the stronger source and 3 for the weaker one
const int NUM_SOURCES = 2;    // Simultaneous sources

// Abstract class of a multi-pitch tracker
class PitchTracker
{
public:
   virtual ~PitchTracker() {}

   // The method "track()" takes F0 candidates and links throught them to form multiple pitch tracks. It assumes
   // that in each frame the max number of simultaneous tracks is 2. Each track is given a unique label (an 
   // integer) in "labels" (2 x nframes) and corresponding F0 values are stores in "tracks" (2 x nframes)
   virtual void track(const MatrixF& f0cands, const int nframes, MatrixInt& labels, MatrixF& tracks) = 0;

protected:
   float calc_dist(float p1, float p2) { return fabs ( p1 - p2 ); }

   // Try to fix an F0 doubling/halving error
   float calc_minDist ( float p1, float p2 ) {
      float f = fabs ( p1 - p2 * 0.5 );
      if ( f > fabs ( p1 - p2 * 2 ) ) f = fabs ( p1 - p2 * 2 );
      if ( f > fabs ( p1 - p2 ) ) f = fabs ( p1 - p2 );
      return ( f );
   }
};


#endif // __PITCH_TRACKER_H

