
/*************************************************************************
 * Rule-based multi-pitch tracker
 *
 * Link through F0 candidates to form pitch tracks, based on the 
 * "birth-death" technique reported in
 *   McAulay, R.J. and Quatieri, T.F. (1986). "Speech analysis/synthesis 
 *   based on a sinusoidal representation," IEEE Trans. ASSP, vol. 34,
 *   no. 4, pp. 744--754, Aug. 1986.
 *
 *************************************************************************/

#ifndef __RULE_BASED_PITCH_TRACKER_H
#define __RULE_BASED_PITCH_TRACKER_H

#include "casagrouping.h"


class RuleTracker : public PitchTracker
{
public:
   virtual ~RuleTracker() {}

   // The method "track()" takes F0 candidates and links throught them to form multiple pitch tracks. It assumes
   // that in each frame the max number of simultaneous tracks is 2. Each track is given a unique label (an 
   // integer) in "labels" (2 x nframes) and corresponding F0 values are stores in "tracks" (2 x nframes)
   virtual void track(const MatrixF& f0cands, const int nframes, MatrixInt& labels, MatrixF& tracks);

private:
   void remove_closeCands(MatrixF& f0Cands, const int nframes);
};


#endif // __RULE_BASED_PITCH_TRACKER_H

